@@ -30,19 +30,17 @@ class VoronoiCoordFinder(object):
     """
     Uses a Voronoi algorithm to determine the coordination for each site in a
     structure.
+
+    Args:
+        structure (Structure): Input structure
+        target ([Element/Specie]): A list of target species to determine
+            coordination for.
     """
 
     # Radius in Angstrom cutoff to look for coordinating atoms
     default_cutoff = 10.0
 
     def __init__(self, structure, target=None):
-        """
-        Args:
-            structure:
-                Input structure
-            target:
-                A list of target species to determine coordination for.
-        """
         self._structure = structure
         if target is None:
             self._target = structure.composition.elements
@@ -57,11 +55,10 @@ class VoronoiCoordFinder(object):
         M. O'Keeffe, Acta Cryst. (1979). A35, 772-775
 
         Args:
-            n:
-                site index
+            n (int): Site index
 
         Returns:
-            A dictionary of sites sharing a common Voronoi facet with the site
+            A dict of sites sharing a common Voronoi facet with the site
             n and their solid angle weights
         """
 
@@ -99,8 +96,7 @@ class VoronoiCoordFinder(object):
         Returns the coordination number of site with index n.
 
         Args:
-            n:
-                site index
+            n (int): Site index
         """
         return sum(self.get_voronoi_polyhedra(n).values())
 
@@ -110,13 +106,10 @@ class VoronoiCoordFinder(object):
         index n.
 
         Args:
-            n:
-                Site number.
-            tol:
-                Weight tolerance to determine if a particular pair is
+            n (int): Site index.
+            tol (float): Weight tolerance to determine if a particular pair is
                 considered a neighbor.
-            Target:
-                Target element
+            target (Element): Target element
 
         Returns:
             Sites coordinating input site.
@@ -140,10 +133,10 @@ class RelaxationAnalyzer(object):
         codes.
 
         Args:
-            initial_structure:
-                Initial input structure to calculation.
-            final_structure:
-                Final output structure from calculation.
+            initial_structure (Structure): Initial input structure to
+                calculation.
+            final_structure (Structure): Final output structure from
+                calculation.
         """
         if final_structure.formula != initial_structure.formula:
             raise ValueError("Initial and final structures have different " +
@@ -183,9 +176,9 @@ class RelaxationAnalyzer(object):
         maximum radius for nearest neighbors.
 
         Args:
-            max_radius:
-                Maximum radius to search for nearest neighbors. This radius is
-                applied to the initial structure, not the final structure.
+            max_radius (float): Maximum radius to search for nearest
+               neighbors. This radius is applied to the initial structure,
+               not the final structure.
 
         Returns:
             Bond distance changes as a dict of dicts. E.g.,
@@ -207,7 +200,11 @@ class RelaxationAnalyzer(object):
 class VoronoiConnectivity(object):
     """
     Computes the solid angles swept out by the shared face of the voronoi
-    polyhedron between two sites
+    polyhedron between two sites.
+
+    Args:
+        structure (Structure): Input structure
+        cutoff (float) Cutoff distance.
     """
 
     # Radius in Angstrom cutoff to look for coordinating atoms
@@ -225,13 +222,14 @@ class VoronoiConnectivity(object):
     @property
     def connectivity_array(self):
         """
+        Provides connectivity array.
+
         Returns:
-            connectivity:
-                an array of shape [atomi, atomj, imagej]. atomi is the
-                index of the atom in the input structure. Since the second
-                atom can be outside of the unit cell, it must be described
-                by both an atom index and an image index. Array data is the
-                solid angle of polygon between atomi and imagej of atomj
+            connectivity: An array of shape [atomi, atomj, imagej]. atomi is
+            the index of the atom in the input structure. Since the second
+            atom can be outside of the unit cell, it must be described
+            by both an atom index and an image index. Array data is the
+            solid angle of polygon between atomi and imagej of atomj
         """
         #shape = [site, axis]
         cart_coords = np.array(self.s.cart_coords)
@@ -298,10 +296,8 @@ class VoronoiConnectivity(object):
         (structure[1]). sitej can be obtained by passing 3, 12 to this function
 
         Args:
-            site_index:
-                index of the site (3 in the example)
-            image_index:
-                index of the image (12 in the example)
+            site_index (int): index of the site (3 in the example)
+            image_index (int): index of the image (12 in the example)
         """
         atoms_n_occu = self.s[site_index].species_and_occu
         lattice = self.s.lattice
@@ -315,10 +311,8 @@ def solid_angle(center, coords):
     center.
 
     Args:
-        center:
-            Center to measure solid angle from.
-        coords:
-            List of coords to determine solid angle.
+        center (3x1 array): Center to measure solid angle from.
+        coords (Nx3 array): List of coords to determine solid angle.
 
     Returns:
         The solid angle.
@@ -339,12 +333,10 @@ def contains_peroxide(structure, relative_cutoff=1.1):
     Determines if a structure contains peroxide anions.
 
     Args:
-        structure:
-            Input structure.
-        relative_cutoff:
-            The peroxide bond distance is 1.49 Angstrom. Relative_cutoff * 1.49
-            stipulates the maximum distance two O atoms must be to each other
-            to be considered a peroxide.
+        structure (Structure): Input structure.
+        relative_cutoff: The peroxide bond distance is 1.49 Angstrom.
+            Relative_cutoff * 1.49 stipulates the maximum distance two O
+            atoms must be to each other to be considered a peroxide.
 
     Returns:
         Boolean indicating if structure contains a peroxide anion.
@@ -356,36 +348,32 @@ def contains_peroxide(structure, relative_cutoff=1.1):
         return False
 
 
-class oxide_type_class():
+class OxideType(object):
     """
     Separate class for determining oxide type.
+
+    Args:
+        structure: Input structure.
+        relative_cutoff: Relative_cutoff * act. cutoff stipulates the max.
+            distance two O atoms must be from each other. Default value is
+            1.1. At most 1.1 is recommended, nothing larger, otherwise the
+            script cannot distinguish between superoxides and peroxides.
     """
     def __init__(self, structure, relative_cutoff=1.1):
-        """
-        Args:
-            structure:
-                Input structure.
-            relative_cutoff:
-                Relative_cutoff * act. cutoff stipulates the max. distance two
-                O atoms must be from each other. Default value is 1.1. At most
-                1.1 is recommended, nothing larger, otherwise the script cannot
-                distinguish between superoxides and peroxides.
-        """
         self.structure = structure
         self.relative_cutoff = relative_cutoff
         self.oxide_type, self.nbonds = self.parse_oxide()
 
     def parse_oxide(self):
         """
-        Determines if an oxide is a peroxide/superoxide/ozonide/normal oxide
+        Determines if an oxide is a peroxide/superoxide/ozonide/normal oxide.
 
         Returns:
-            oxide_type:
-                Type of oxide - ozonide/peroxide/superoxide/hydroxide/None
-            nbonds:
-                Number of peroxide/superoxide/hydroxide bonds in structure
+            oxide_type (str): Type of oxide
+            ozonide/peroxide/superoxide/hydroxide/None.
+            nbonds (int): Number of peroxide/superoxide/hydroxide bonds in
+            structure.
         """
-
         structure = self.structure
         relative_cutoff = self.relative_cutoff
         o_sites_frac_coords = []
@@ -451,16 +439,13 @@ def oxide_type(structure, relative_cutoff=1.1, return_nbonds=False):
     Determines if an oxide is a peroxide/superoxide/ozonide/normal oxide
 
     Args:
-        structure:
-            Input structure.
-        relative_cutoff:
-            Relative_cutoff * act. cutoff stipulates the max. distance two
-            O atoms must be from each other.
-        return_nbonds:
-            Should number of bonds be requested?
+        structure (Structure): Input structure.
+        relative_cutoff (float): Relative_cutoff * act. cutoff stipulates the
+            max distance two O atoms must be from each other.
+        return_nbonds (bool): Should number of bonds be requested?
     """
 
-    ox_obj = oxide_type_class(structure, relative_cutoff)
+    ox_obj = OxideType(structure, relative_cutoff)
     if return_nbonds:
         return ox_obj.oxide_type, ox_obj.nbonds
     else:
