@@ -10,6 +10,8 @@ Boltztrap has been developped by Georg Madsen.
 
 http://www.icams.de/content/departments/ams/madsen/boltztrap.html
 
+You need the version 1.2.3
+
 References are::
 
     Madsen, G. K. H., and Singh, D. J. (2006).
@@ -34,10 +36,11 @@ import numpy as np
 import tempfile
 from pymatgen.core.lattice import Lattice
 from pymatgen.symmetry.finder import SymmetryFinder
-from pymatgen.electronic_structure.dos import Dos, Spin
+from pymatgen.electronic_structure.dos import Dos, Spin, CompleteDos
+from pymatgen.electronic_structure.core import Orbital
 from pymatgen.electronic_structure.plotter import DosPlotter
-from pymatgen.util.io_utils import which
-from pymatgen.util.decorators import requires
+from monty.os.path import which
+from monty.dev import requires
 from pymatgen.core.units import Energy, Length
 from pymatgen.core.physical_constants import e, ELECTRON_MASS
 import subprocess
@@ -50,7 +53,19 @@ except ImportError:
 
 class BoltztrapRunner():
     """
-    This class is used to run Boltztrap on a band structure object
+    This class is used to run Boltztrap on a band structure object.
+
+    Args:
+        bs: A band structure object
+        nelec: The number of electrons
+        dos_type: Two options here for the band structure integration: "HISTO"
+            (histogram) or "TETRA" using the tetrahedon method. TETRA
+            gives typically better results especially for DOSes but takes
+            more time
+        energy_grid: The energy steps used for the integration. in eV
+        lpfac: The number of interpolation points in the real space. By
+            default 10 gives 10 time more points in the real space than
+            the number of kpoints given in reciprocal space
     """
 
     @requires(which('x_trans'),
@@ -59,34 +74,14 @@ class BoltztrapRunner():
               "http://www.icams.de/content/departments/ams/madsen/boltztrap"
               ".html and follow the instructions in the README to compile "
               "Bolztrap accordingly. Then add x_trans to your path")
+
     def __init__(self, bs, nelec, dos_type="HISTO", energy_grid=0.005,
-                 lpfac=10, sym_nb=None):
-        """
-        Args:
-            bs:
-                A band structure object
-            nelec:
-                the number of electrons
-            dos_type:
-                two options here for the band structure integration: "HISTO"
-                (histogram) or "TETRA" using the tetrahedon method. TETRA
-                gives typically better results especially for DOSes but takes
-                more time
-            energy_grid:
-                the energy steps used for the integration. in eV
-            lpfac:
-                the number of interpolation points in the real space. By
-                default 10 gives 10 time more points in the real space than
-                the number of kpoints given in reciprocal space
-            sym_nb:
-                ?
-        """
+                 lpfac=10):
         self.lpfac = lpfac
         self._bs = bs
         self._nelec = nelec
         self.dos_type = dos_type
         self.energy_grid = energy_grid
-        self.sym_nb = sym_nb
         self.error = []
 
     def _make_energy_file(self, file_name):
@@ -126,27 +121,107 @@ class BoltztrapRunner():
                                    for row in c]))
                 f.write('\n')
 
+    def _make_def_file(self, def_file_name):
+        with open(def_file_name,'w') as f:
+            so = ""
+            if self._bs.is_spin_polarized:
+                so = "so"
+            f.write("5, 'boltztrap.intrans',      'old',    'formatted',0\n"+
+                    "6,'boltztrap.outputtrans',      'unknown',    'formatted',0\n"+
+                    "20,'boltztrap.struct',         'old',    'formatted',0\n"+
+                    "10,'boltztrap.energy"+so+"',         'old',    'formatted',0\n"+
+                    "48,'boltztrap.engre',         'unknown',    'unformatted',0\n"+
+                    "49,'boltztrap.transdos',        'unknown',    'formatted',0\n"+
+                    "50,'boltztrap.sigxx',        'unknown',    'formatted',0\n"+
+                    "51,'boltztrap.sigxxx',        'unknown',    'formatted',0\n"+
+                    "21,'boltztrap.trace',           'unknown',    'formatted',0\n"+
+                    "22,'boltztrap.condtens',           'unknown',    'formatted',0\n"+
+                    "24,'boltztrap.halltens',           'unknown',    'formatted',0\n"+
+                    "30,'boltztrap_BZ.cube',           'unknown',    'formatted',0\n"+
+                    "35,'boltztrap.banddat',           'unknown',    'formatted',0\n"+
+                    "36,'boltztrap_band.gpl',           'unknown',    'formatted',0\n")
+
+    def _make_proj_files(self, file_name, def_file_name):
+        from pymatgen.electronic_structure.core import Orbital
+        for o in Orbital.all_orbitals:
+            for site_nb in range(0, len(self._bs._structure.sites)):
+                if o in self._bs._projections[Spin.up][0][0]:
+                    with open(file_name+"_"+str(site_nb)+"_"+str(o), 'w') as f:
+                        f.write(self._bs._structure.composition.formula+"\n")
+                        f.write(str(len(self._bs.kpoints))+"\n")
+                        for i in range(len(self._bs.kpoints)):
+                            tmp_proj = []
+                            for spin in self._bs._bands:
+                                for j in range(int(math.floor(self._bs._nb_bands * 0.9))):
+                                    tmp_proj.append(self._bs._projections[spin][j][i][o][site_nb])
+                            #TODO deal with the sorting going on at the energy level!!!
+                            f.write("%12.8f %12.8f %12.8f %d\n"
+                                    % (self._bs.kpoints[i].frac_coords[0],
+                                       self._bs.kpoints[i].frac_coords[1],
+                                       self._bs.kpoints[i].frac_coords[2], len(tmp_proj)))
+                            for j in range(len(tmp_proj)):
+                                f.write("%18.8f\n" % float(tmp_proj[j]))
+        with open(def_file_name,'w') as f:
+            so = ""
+            if self._bs.is_spin_polarized:
+                so = "so"
+            f.write("5, 'boltztrap.intrans',      'old',    'formatted',0\n"+
+                    "6,'boltztrap.outputtrans',      'unknown',    'formatted',0\n"+
+                    "20,'boltztrap.struct',         'old',    'formatted',0\n"+
+                    "10,'boltztrap.energy"+so+"',         'old',    'formatted',0\n"+
+                    "48,'boltztrap.engre',         'unknown',    'unformatted',0\n"+
+                    "49,'boltztrap.transdos',        'unknown',    'formatted',0\n"+
+                    "50,'boltztrap.sigxx',        'unknown',    'formatted',0\n"+
+                    "51,'boltztrap.sigxxx',        'unknown',    'formatted',0\n"+
+                    "21,'boltztrap.trace',           'unknown',    'formatted',0\n"+
+                    "22,'boltztrap.condtens',           'unknown',    'formatted',0\n"+
+                    "24,'boltztrap.halltens',           'unknown',    'formatted',0\n"+
+                    "30,'boltztrap_BZ.cube',           'unknown',    'formatted',0\n"+
+                    "35,'boltztrap.banddat',           'unknown',    'formatted',0\n"+
+                    "36,'boltztrap_band.gpl',           'unknown',    'formatted',0\n")
+            i = 1000
+            for o in Orbital.all_orbitals:
+                for site_nb in range(0, len(self._bs._structure.sites)):
+                    if o in self._bs._projections[Spin.up][0][0]:
+                        f.write(str(i)+",\'"+file_name+"_"+str(site_nb)+"_"+str(o)
+                                + "\' \'old\', \'formatted\',0\n")
+                        i += 1
+
     def _make_intrans_file(self, file_name,
-                           doping=[1e15, 1e16, 1e17, 1e18, 1e19, 1e20]):
-        with open(file_name, 'w') as fout:
-            fout.write("GENE          # use generic interface\n")
-            fout.write("1 0 0 0.0         # iskip (not presently used) idebug setgap shiftgap \n")
-            fout.write(
-                "0.0 %f 0.1 %6.1f     # Fermilevel (Ry),energygrid,energy span around Fermilevel, number of electrons\n"
-                % (Energy(self.energy_grid, "eV").to("Ry"), self._nelec))
-            fout.write("CALC                    # CALC (calculate expansion coeff), NOCALC read from file\n")
-            fout.write("%d                        # lpfac, number of latt-points per k-point\n" % self.lpfac)
-            fout.write("BOLTZ                     # run mode (only BOLTZ is supported)\n")
-            fout.write(".15                       # (efcut) energy range of chemical potential\n")
-            fout.write("800. 100.                  # Tmax, temperature grid\n")
-            fout.write("-1.  # energyrange of bands given DOS output sig_xxx and dos_xxx (xxx is band number)\n")
-            fout.write(self.dos_type+"\n")
-            fout.write("1 0 0 -1\n")
-            fout.write(str(2*len(doping))+"\n")
-            for d in doping:
-                fout.write(str(d)+"\n")
-            for d in doping:
-                fout.write(str(-d)+"\n")
+                           doping=[1e15, 1e16, 1e17, 1e18, 1e19, 1e20], type="BOLTZ", band_nb=None):
+        if type == "BOLTZ":
+            with open(file_name, 'w') as fout:
+                fout.write("GENE          # use generic interface\n")
+                fout.write("1 0 0 0.0         # iskip (not presently used) idebug setgap shiftgap \n")
+                fout.write(
+                    "0.0 %f 0.1 %6.1f     # Fermilevel (Ry),energygrid,energy span around Fermilevel, "
+                    "number of electrons\n"
+                    % (Energy(self.energy_grid, "eV").to("Ry"), self._nelec))
+                fout.write("CALC                    # CALC (calculate expansion coeff), NOCALC read from file\n")
+                fout.write("%d                        # lpfac, number of latt-points per k-point\n" % self.lpfac)
+                fout.write("BOLTZ                     # run mode (only BOLTZ is supported)\n")
+                fout.write(".15                       # (efcut) energy range of chemical potential\n")
+                fout.write("800. 100.                  # Tmax, temperature grid\n")
+                fout.write("-1.  # energyrange of bands given DOS output sig_xxx and dos_xxx (xxx is band number)\n")
+                fout.write(self.dos_type+"\n")
+                fout.write("0 0 0 0 0\n")
+                fout.write(str(2*len(doping))+"\n")
+                for d in doping:
+                    fout.write(str(d)+"\n")
+                for d in doping:
+                    fout.write(str(-d)+"\n")
+        elif type == "FERMI":
+            with open(file_name, 'w') as fout:
+                fout.write("GENE          # use generic interface\n")
+                fout.write("1 0 0 0.0         # iskip (not presently used) idebug setgap shiftgap \n")
+                fout.write(
+                    "0.0 %f 0.1 %6.1f     # Fermilevel (Ry),energygrid,energy span around Fermilevel, "
+                    "number of electrons\n"
+                    % (Energy(self.energy_grid, "eV").to("Ry"), self._nelec))
+                fout.write("CALC                    # CALC (calculate expansion coeff), NOCALC read from file\n")
+                fout.write("%d                        # lpfac, number of latt-points per k-point\n" % self.lpfac)
+                fout.write("FERMI                     # run mode (only BOLTZ is supported)\n")
+                fout.write(str(band_nb))
 
     def _make_all_files(self, path):
         if self._bs.is_spin_polarized:
@@ -155,8 +230,11 @@ class BoltztrapRunner():
             self._make_energy_file(os.path.join(path, "boltztrap.energy"))
         self._make_struc_file(os.path.join(path, "boltztrap.struct"))
         self._make_intrans_file(os.path.join(path, "boltztrap.intrans"))
+        self._make_def_file("BoltzTraP.def")
+        if len(self._bs._projections) != 0:
+            self._make_proj_files(os.path.join(path,"boltztrap.proj"), os.path.join(path, "BoltzTraP.def"))
 
-    def run(self, prev_sigma=None, path_dir=None):
+    def run(self, prev_sigma=None, path_dir=None, convergence=True):
         dir_bz_name = "boltztrap"
         path_dir_orig = path_dir
         if path_dir is None:
@@ -208,7 +286,7 @@ class BoltztrapRunner():
         doping_ok = True
         for doping in ['n', 'p']:
             for c in analyzer.mu_doping[doping]:
-                if len(analyzer.mu_doping[doping][c])!=len(analyzer.doping[doping]):
+                if len(analyzer.mu_doping[doping][c]) != len(analyzer.doping[doping]):
                     doping_ok = False
                     break
                 if doping == 'p' and \
@@ -216,7 +294,7 @@ class BoltztrapRunner():
                     doping_ok = False
                     break
                 if doping == 'n' and sorted(analyzer.mu_doping[doping][c]) != analyzer.mu_doping[doping][c]:
-                    doping_ok=False
+                    doping_ok = False
                     break
         if not doping_ok:
             self.energy_grid /= 10
@@ -227,6 +305,8 @@ class BoltztrapRunner():
             self.run(prev_sigma=None, path_dir=path_dir_orig)
         analyzer = BoltztrapAnalyzer.from_files(path_dir)
         #here, we test if a property (eff_mass tensor) converges
+        if convergence is False:
+            return path_dir
         if prev_sigma is None or \
                 abs(sum(analyzer.get_eig_average_eff_mass_tensor()['n']) / 3
                         - prev_sigma)\
@@ -243,11 +323,6 @@ class BoltztrapRunner():
             self.run(
                 prev_sigma=sum(analyzer.get_eig_average_eff_mass_tensor()
                                ['n']) / 3, path_dir=path_dir_orig)
-        else:
-            print "converged", \
-                abs(sum(analyzer.get_eig_average_eff_mass_tensor()['n'])/3
-                    - prev_sigma) / prev_sigma, \
-                self.lpfac, analyzer.get_average_eff_mass_tensor(300, 1e18)
         return path_dir
 
 
@@ -266,74 +341,63 @@ class BoltztrapError(Exception):
 
 class BoltztrapAnalyzer():
     """
-    class used to store all the data from a boltztrap run
+    Class used to store all the data from a boltztrap run
     """
 
     def __init__(self, gap, mu_steps, cond, seebeck, kappa, hall, doping,
                  mu_doping, seebeck_doping, cond_doping, kappa_doping,
-                 hall_doping, dos, carrier_conc, vol, warning):
+                 hall_doping, dos, dos_partial, carrier_conc, vol, warning):
         """
         Constructor taking directly all the data generated by Boltztrap. You
         won't probably use it directly but instead use the from_files and
         from_dict methods.
 
         Args:
-            gap:
-                The gap after interpolation in eV
-            mu_steps:
-                The steps of electron chemical potential (or Fermi level) in
-                 eV.
-            cond:
-                The electronic conductivity tensor divided by a constant
+            gap: The gap after interpolation in eV
+            mu_steps: The steps of electron chemical potential (or Fermi
+                level) in eV.
+            cond: The electronic conductivity tensor divided by a constant
                 relaxation time (sigma/tau) at different temperature and
                 fermi levels.
                 The format is {temperature: [array of 3x3 tensors at each
                 fermi level in mu_steps]}. The units are 1/(Ohm*m*s).
-            seebeck:
-                The Seebeck tensor at different temperatures and fermi levels
-                The format is {temperature: [array of 3x3 tensors at each
-                fermi level in mu_steps]}. The units are V/K
-            kappa:
-                The electronic thermal conductivity tensor divided by a
+            seebeck: The Seebeck tensor at different temperatures and fermi
+                levels. The format is {temperature: [array of 3x3 tensors at
+                each fermi level in mu_steps]}. The units are V/K
+            kappa: The electronic thermal conductivity tensor divided by a
                 constant relaxation time (kappa/tau) at different temperature
                 and fermi levels. The format is {temperature: [array of 3x3
                 tensors at each fermi level in mu_steps]}
                 The units are W/(m*K*s)
-            hall:
-                The hall tensor at different temperature and fermi levels
+            hall: The hall tensor at different temperature and fermi levels
                 The format is {temperature: [array of 27 coefficients list at
                 each fermi level in mu_steps]}
                 The units are m^3/C
-            doping:
-                The different doping levels that have been given to Boltztrap
-                The format is {'p':[],'n':[]} with an array of doping levels
-                The units are cm^-3
-            mu_doping:
-                Gives the electron chemical potential (or Fermi level) for a
-                given set of doping.
+            doping: The different doping levels that have been given to
+                Boltztrap. The format is {'p':[],'n':[]} with an array of
+                doping levels. The units are cm^-3
+            mu_doping: Gives the electron chemical potential (or Fermi level)
+                for a given set of doping.
                 Format is {'p':{temperature: [fermi levels],'n':{temperature:
                 [fermi levels]}}
                 the fermi level array is ordered according to the doping
                 levels in doping units for doping are in cm^-3 and for Fermi
                 level in eV
-            seebeck_doping:
-                The Seebeck tensor at different temperatures and doping levels
-                The format is {'p': {temperature: [Seebeck tensors]},
-                'n':{temperature: [Seebeck tensors]}}
+            seebeck_doping: The Seebeck tensor at different temperatures and
+                doping levels. The format is {'p': {temperature: [Seebeck
+                tensors]}, 'n':{temperature: [Seebeck tensors]}}
                 The [Seebeck tensors] array is ordered according to the
                 doping levels in doping units for doping are in cm^-3 and for
                 Seebeck in V/K
-            cond_doping:
-                The electronic conductivity tensor divided by a constant
-                relaxation time (sigma/tau) at different temperatures and
-                doping levels
+            cond_doping: The electronic conductivity tensor divided by a
+                constant relaxation time (sigma/tau) at different
+                temperatures and doping levels
                 The format is {'p':{temperature: [conductivity tensors]},
                 'n':{temperature: [conductivity tensors]}}
                 The [conductivity tensors] array is ordered according to the
                 doping levels in doping units for doping are in cm^-3 and for
                 conductivity in 1/(Ohm*m*s)
-            kappa_doping:
-                The thermal conductivity tensor divided by a constant
+            kappa_doping: The thermal conductivity tensor divided by a constant
                 relaxation time (kappa/tau) at different temperatures and
                 doping levels.
                 The format is {'p':{temperature: [thermal conductivity
@@ -341,25 +405,22 @@ class BoltztrapAnalyzer():
                 The [thermal conductivity tensors] array is ordered according
                 to the doping levels in doping units for doping are in cm^-3
                 and for thermal conductivity in W/(m*K*s)
-            hall_doping:
-                The Hall tensor at different temperatures and doping levels
+            hall_doping: The Hall tensor at different temperatures and doping
+                levels.
                 The format is {'p':{temperature: [Hall tensors]},
                 'n':{temperature: [Hall tensors]}}
                 The [Hall tensors] array is ordered according to the doping
                 levels in doping and each Hall tensor is represented by a 27
                 coefficients list.
                 The units are m^3/C
-            the concentration of carriers:
-                in electron (or hole) per unit cell
-            dos:
-                The dos computed by Boltztrap
-                given as a pymatgen Dos object
-            vol:
-                the volume of the unit cell in angstrom cube (A^3)
-            warning:
-                True if Boltztrap spitted out a warning
+            carrier_conc: The concentration of carriers in electron (or hole)
+                per unit cell
+            dos: The dos computed by Boltztrap given as a pymatgen Dos object
+            dos_partial: Data for the partial DOS projected on sites and
+                orbitals
+            vol: Volume of the unit cell in angstrom cube (A^3)
+            warning: True if Boltztrap spitted out a warning
         """
-
         self.gap = gap
         self.mu_steps = mu_steps
         self.cond = cond
@@ -376,6 +437,7 @@ class BoltztrapAnalyzer():
         self.carrier_conc = carrier_conc
         self.dos = dos
         self.vol = vol
+        self._dos_partial = dos_partial
 
     @staticmethod
     def _make_boltztrap_analyzer_from_data(
@@ -458,16 +520,37 @@ class BoltztrapAnalyzer():
             else:
                 hall_doping['p'][data_doping_hall[i][0]].append(hall_tens)
 
-        for t in data_dos:
+        for t in data_dos['total']:
             dos_full['energy'].append(t[0])
             dos_full['density'].append(t[1])
 
         dos = Dos(efermi, dos_full['energy'], {Spin.up: dos_full['density']})
+        dos_partial = data_dos['partial']
+
         return BoltztrapAnalyzer(
             gap, mu_steps, cond, seebeck, kappa, hall, new_doping, mu_doping,
-            seebeck_doping, cond_doping, kappa_doping, hall_doping, dos, carrier_conc,
+            seebeck_doping, cond_doping, kappa_doping, hall_doping, dos, dos_partial, carrier_conc,
             vol, warning)
 
+    def get_complete_dos(self, structure):
+        """
+        Gives a CompleteDos object with the DOS from the interpolated projected band structure
+        Args:
+            the structure (necessary to identify sites for projection)
+
+        Returns:
+            a CompleteDos object
+        """
+        pdoss = {}
+        for s in self._dos_partial:
+            if structure.sites[int(s)] not in pdoss:
+                pdoss[structure.sites[int(s)]] = {}
+            for o in self._dos_partial[s]:
+                if Orbital.from_string(o) not in pdoss[structure.sites[int(s)]]:
+                    pdoss[structure.sites[int(s)]][Orbital.from_string(o)] = {}
+                pdoss[structure.sites[int(s)]][Orbital.from_string(o)][Spin.up] = self._dos_partial[s][o]
+        return CompleteDos(structure, total_dos=self.dos, pdoss=pdoss)
+
     def get_mu_bounds(self, temp=300):
         return min(self.mu_doping['p'][temp]), max(self.mu_doping['n'][temp])
 
@@ -483,13 +566,11 @@ class BoltztrapAnalyzer():
         -multiple bands
 
         Args:
-            temperature:
-                the temperature in K
-            doping:
-                the doping in cm^-3
+            temperature: The temperature in K
+            doping: The doping in cm^-3
 
         Returns:
-            a dictionnary {'p':[[]],'n':[[]]}
+            a dictionary {'p':[[]],'n':[[]]}
             The arrays are 3x3 and represent the effective mass tensor
             The 'p' links to hole effective mass tensor and 'n' to electron
             effective mass tensor.
@@ -517,10 +598,8 @@ class BoltztrapAnalyzer():
         -multiple bands
 
         Args:
-            temperature:
-                the temperature in K
-            doping:
-                the doping in cm^-3
+            temperature: The temperature in K
+            doping: The doping in cm^-3
 
         Returns:
             a dictionnary {'p':[],'n':[]}
@@ -529,20 +608,39 @@ class BoltztrapAnalyzer():
             electron effective mass tensor.
         """
         return {'p':
-                sorted(np.linalg.eig(self.get_average_eff_mass_tensor(
+                sorted(np.linalg.eigh(self.get_average_eff_mass_tensor(
                     temperature=temperature, doping=doping)['p'])[0]),
                 'n':
-                sorted(np.linalg.eig(self.get_average_eff_mass_tensor(
+                sorted(np.linalg.eigh(self.get_average_eff_mass_tensor(
                     temperature=temperature, doping=doping)['n'])[0])}
 
+    def get_seebeck_eig(self):
+        """
+        Gives the three eigenvalues of the seebeck tensor at different doping levels
+
+        Returns:
+            a dictionnary {'p':[],'n':[]}
+            The list contains the sorted three eigenvalues of the symmetric
+            Seebeck tensor. The 'p' links to Seebeck at p-type doping and 'n' to
+            the Seebeck at n-type doping.
+        """
+
+        full_tensor = self.seebeck_doping
+        result = {doping: {t: [] for t in self.seebeck_doping[doping]} for doping in self.seebeck_doping}
+        for doping in full_tensor:
+            for temp in full_tensor[doping]:
+                for i in range(len(self.doping[doping])):
+                    result[doping][temp].append(sorted(np.linalg.eigh(full_tensor[doping][temp][i])[0]))
+        return result
+
+
     @staticmethod
     def from_files(path_dir):
         """
         get a BoltztrapAnalyzer object from a set of files
 
         Args:
-            path_dir:
-                directory where the boltztrap files are
+            path_dir: directory where the boltztrap files are
 
         Returns:
             a BoltztrapAnalyzer object
@@ -568,13 +666,31 @@ class BoltztrapAnalyzer():
                 if not line.startswith("#"):
                     data_hall.append([float(c) for c in line.split()])
 
-        data_dos = []
+        data_dos = {'total': [], 'partial':{}}
         with open(os.path.join(path_dir, "boltztrap.transdos"), 'r') as f:
+            count_series = 0
             for line in f:
                 if not line.startswith(" #"):
-                    data_dos.append([Energy(line.split()[0], "Ry").to("eV"),
-                                     2 * Energy(line.split()[1],
-                                                "eV").to("Ry")])
+                    data_dos['total'].append([Energy(float(line.split()[0]), "Ry").to("eV"),
+                                              float(line.split()[1])])
+                else:
+                    count_series += 1
+                if count_series>1:
+                    break
+                    #data_dos['total'].append([float(line.split()[0]),
+                    #                          float(line.split()[1])])
+
+        for file_name in os.listdir(path_dir):
+            if file_name.endswith("transdos") and file_name != 'boltztrap.transdos':
+                tokens = file_name.split(".")[1].split("_")
+                with open(os.path.join(path_dir, file_name), 'r') as f:
+                    for line in f:
+                        if not line.startswith(" #"):
+                            if tokens[1] not in data_dos['partial']:
+                                data_dos['partial'][tokens[1]] = {}
+                            if tokens[2] not in data_dos['partial'][tokens[1]]:
+                                data_dos['partial'][tokens[1]][tokens[2]] = []
+                            data_dos['partial'][tokens[1]][tokens[2]].append(float(line.split()[1]))
 
         with open(os.path.join(path_dir, "boltztrap.outputtrans"), 'r') as f:
             warning = False
@@ -601,13 +717,13 @@ class BoltztrapAnalyzer():
                 if line.startswith("Egap:"):
                     gap = float(line.split()[1])
         if len(doping) != 0:
-            with open(os.path.join(path_dir, "fort.26"), 'r') as f:
+            with open(os.path.join(path_dir, "boltztrap.condtens_fixdoping"), 'r') as f:
                 for line in f:
                     if not line.startswith("#") and len(line) > 2:
                         data_doping_full.append([float(c)
                                                  for c in line.split()])
 
-            with open(os.path.join(path_dir, "fort.27"), 'r') as f:
+            with open(os.path.join(path_dir, "boltztrap.halltens_fixdoping"), 'r') as f:
                 for line in f:
                     if not line.startswith("#") and len(line) > 2:
 
@@ -639,6 +755,7 @@ class BoltztrapAnalyzer():
                    'kappa_doping': self.kappa_doping,
                    'hall_doping': self.hall_doping,
                    'dos': self.dos.to_dict,
+                   'dos_partial': self._dos_partial,
                    'carrier_conc': self.carrier_conc,
                    'vol': self.vol}
         return clean_json(results)
@@ -695,21 +812,19 @@ class BoltztrapAnalyzer():
              'n': {int(d): [_make_float_hall(v)
                             for v in data['hall_doping']['n'][d]]
                    for d in data['hall_doping']['n']}},
-            Dos.from_dict(data['dos']), data['carrier_conc'],
+            Dos.from_dict(data['dos']), data['carrier_conc'], data['dos_partial'],
             data['vol'], str(data['warning']))
 
 
 class BoltztrapPlotter():
     """
-    class containing methods to plot the data from Boltztrap
+    class containing methods to plot the data from Boltztrap.
+
+    Args:
+        bz: a BoltztrapAnalyzer object
     """
 
     def __init__(self, bz):
-        """
-        Args:
-            bz:
-                a BoltztrapAnalyzer object
-        """
         self._bz = bz
 
     def _plot_doping(self, temp):
@@ -743,64 +858,105 @@ class BoltztrapPlotter():
         plt.axvline(0.0, color='k', linewidth=3.0)
         plt.axvline(self._bz.gap, color='k', linewidth=3.0)
 
-    def plot_seebeck(self, temp=300):
-        plt.plot(self._bz.mu_steps, [np.linalg.eig(c)[0] * 1e6
+    def plot_seebeck(self, temp=300, xlim=None):
+        """
+        Plot the seebeck coefficient in function of Fermi level
+
+        Args:
+            temp:
+                the temperature
+            xlim:
+                a list of min and max fermi energy by default (0, and band gap)
+        Returns:
+            a matplotlib object
+        """
+        plt.plot(self._bz.mu_steps, [np.linalg.eigh(c)[0] * 1e6
                                      for c in self._bz.seebeck[temp]],
                  linewidth=3.0)
         self._plot_BG_limits()
         self._plot_doping(temp)
         plt.legend(['S$_1$', 'S$_2$', 'S$_3$'])
-        plt.xlim(-0.5, self._bz.gap+0.5)
-        plt.ylabel("Seebeck coefficient ($\mu$V/K)", fontsize=30.0)
+        if xlim is None:
+            plt.xlim(-0.5, self._bz.gap + 0.5)
+        else:
+            plt.xlim(xlim[0], xlim[1])
+        plt.ylabel("Seebeck \n coefficient  ($\mu$V/K)", fontsize=30.0)
         plt.xlabel("E-E$_f$ (eV)", fontsize=30)
         plt.xticks(fontsize=25)
         plt.yticks(fontsize=25)
-        plt.show()
+        return plt
 
-    def plot_power_factor(self, temp=300):
-        print "blah"
-        matrix = []
-        for i in range(len(self._bz.mu_steps)):
-            matrix.append(np.dot(np.dot(self._bz.seebeck[temp][i],
-                                        self._bz.seebeck[temp][i]),
-                                 self._bz.cond[temp][i]))
-        plt.plot(self._bz.mu_steps, [sorted(np.linalg.eig(c)[0] * 1e6 * 0.01)
-                                     for c in matrix],
-                 linewidth=3.0)
-        self._plot_BG_limits()
-        self._plot_doping(temp)
-        plt.xlim(-0.5, self._bz.gap + 0.5)
-        plt.ylabel("power factor (S$^2$ * $\sigma$/${\\tau}$)", fontsize=30)
-        plt.xlabel("E-E$_f$ (eV)", fontsize=30)
-        plt.xticks(fontsize=25)
-        plt.yticks(fontsize=25)
-        plt.show()
+    def plot_conductivity(self, temp=300, tau=None, xlim=None):
+        """
+        Plot the conductivity in function of Fermi level. Semi-log plot
 
-    def plot_conductivity(self, temp=300):
-        plt.semilogy(self._bz.mu_steps, [sorted(np.linalg.eig(c)[0] * 0.01)
-                                         for c in self._bz.cond[temp]],
-                     linewidth=3.0)
+        Args:
+            temp: the temperature
+            xlim: a list of min and max fermi energy by default (0, and band
+                gap)
+            tau: A relaxation time in s. By default none and the plot is by
+               units of relaxation time
+
+        Returns:
+            a matplotlib object
+        """
+        if tau is None:
+            plt.semilogy(self._bz.mu_steps, [sorted(np.linalg.eigh(c)[0] * 0.01)
+                                             for c in self._bz.cond[temp]],
+                         linewidth=3.0)
+        else:
+            plt.semilogy(self._bz.mu_steps, [sorted(np.linalg.eigh(c)[0] * 0.01 * tau)
+                                             for c in self._bz.cond[temp]],
+                         linewidth=3.0)
         self._plot_BG_limits()
         self._plot_doping(temp)
         plt.legend(['$\sigma_1$', '$\sigma_2$', '$\sigma_3$'])
-        plt.xlim(-0.5, self._bz.gap + 0.5)
-        plt.ylim([1e13, 1e20])
-        plt.ylabel("conductivity, $\sigma$/${\\tau}$ (1/($\Omega$ m s))",
-                   fontsize=30.0)
+        if xlim is None:
+            plt.xlim(-0.5, self._bz.gap + 0.5)
+        else:
+            plt.xlim(xlim)
+        if tau is None:
+            plt.ylim([1e13, 1e20])
+        else:
+            plt.ylim([1e13*tau,1e20*tau])
+        if tau is None:
+            plt.ylabel("conductivity, $\sigma$/${\\tau}$ (1/($\Omega$ m s))",
+                       fontsize=30.0)
+        else:
+            plt.ylabel("conductivity,\n $\sigma$ (1/($\Omega$ m))",
+                       fontsize=30.0)
         plt.xlabel("E-E$_f$ (eV)", fontsize=30.0)
         plt.xticks(fontsize=25)
         plt.yticks(fontsize=25)
-        plt.show()
+        return plt
 
-    def plot_dos(self):
-        plotter = DosPlotter(sigma=0.05)
+    def plot_dos(self, sigma=0.05):
+        """
+        plot dos
+
+        Args:
+            sigma: a smearing
+
+        Returns:
+            a matplotlib object
+        """
+        plotter = DosPlotter(sigma=sigma)
         plotter.add_dos("t", self._bz.dos)
-        plotter.get_plot().show()
+        return plotter.get_plot()
 
     def plot_carriers(self, temp=300):
+        """
+        Plot the carrier concentration in function of Fermi level
+
+        Args:
+            temp: the temperature
+
+        Returns:
+            a matplotlib object
+        """
         plt.semilogy(self._bz.mu_steps,
-                       abs(self._bz.carrier_conc[temp]/(self._bz.vol*1e-24)),
-                       linewidth=3.0, color='r')
+                     abs(self._bz.carrier_conc[temp]/(self._bz.vol*1e-24)),
+                     linewidth=3.0, color='r')
         self._plot_BG_limits()
         self._plot_doping(temp)
         plt.xlim(-0.5, self._bz.gap+0.5)
@@ -809,5 +965,5 @@ class BoltztrapPlotter():
         plt.xlabel("E-E$_f$ (eV)", fontsize=30)
         plt.xticks(fontsize=25)
         plt.yticks(fontsize=25)
-        plt.show()
+        return plt
 
