@@ -78,35 +78,26 @@ class NwTask(MSONable):
         flexibility.
 
         Args:
-            charge:
-                Charge of the molecule. If None, charge on molecule is used.
-                Defaults to None. This allows the input file to be set a
+            charge: Charge of the molecule. If None, charge on molecule is
+                used. Defaults to None. This allows the input file to be set a
                 charge independently from the molecule itself.
-            spin_multiplicity:
-                Spin multiplicity of molecule. Defaults to None,
+            spin_multiplicity: Spin multiplicity of molecule. Defaults to None,
                 which means that the spin multiplicity is set to 1 if the
                 molecule has no unpaired electrons and to 2 if there are
                 unpaired electrons.
-            basis_set:
-                The basis set used for the task as a dict. E.g.,
+            basis_set: The basis set used for the task as a dict. E.g.,
                 {"C": "6-311++G**", "H": "6-31++G**"}.
-            title:
-                Title for the task. Defaults to None, which means a title
+            title: Title for the task. Defaults to None, which means a title
                 based on the theory and operation of the task is
                 autogenerated.
-            theory:
-                The theory used for the task. Defaults to "dft".
-            operation:
-                The operation for the task. Defaults to "optimize".
-
-            theory_directives:
-                A dict of theory directives. For example,
+            theory: The theory used for the task. Defaults to "dft".
+            operation: The operation for the task. Defaults to "optimize".
+            theory_directives: A dict of theory directives. For example,
                 if you are running dft calculations, you may specify the
                 exchange correlation functional using {"xc": "b3lyp"}.
-            alternate_directives:
-                A dict of alternate directives. For example, to perform
-                cosmo calculations and dielectric constant of 78,
-                you'd supply {'cosmo': {"dielectric": 78}}.
+            alternate_directives: A dict of alternate directives. For
+                example, to perform cosmo calculations and dielectric
+                constant of 78, you'd supply {'cosmo': {"dielectric": 78}}.
         """
         #Basic checks.
         if theory.lower() not in NwTask.theories.keys():
@@ -187,36 +178,28 @@ task $theory $operation""")
         flexibility.
 
         Args:
-            mol:
-                Input molecule
-            charge:
-                Charge of the molecule. If None, charge on molecule is used.
-                Defaults to None. This allows the input file to be set a
+            mol: Input molecule
+            charge: Charge of the molecule. If None, charge on molecule is
+                used. Defaults to None. This allows the input file to be set a
                 charge independently from the molecule itself.
-            spin_multiplicity:
-                Spin multiplicity of molecule. Defaults to None,
+            spin_multiplicity: Spin multiplicity of molecule. Defaults to None,
                 which means that the spin multiplicity is set to 1 if the
                 molecule has no unpaired electrons and to 2 if there are
                 unpaired electrons.
-            basis_set:
-                The basis set to be used as string or a dict. E.g.,
+            basis_set: The basis set to be used as string or a dict. E.g.,
                 {"C": "6-311++G**", "H": "6-31++G**"} or "6-31G". If string,
                 same basis set is used for all elements.
-            title:
-                Title for the task. Defaults to None, which means a title
+            title: Title for the task. Defaults to None, which means a title
                 based on the theory and operation of the task is
                 autogenerated.
-            theory:
-                The theory used for the task. Defaults to "dft".
-            operation:
-                The operation for the task. Defaults to "optimize".
-            theory_directives:
-                A dict of theory directives. For example,
+            theory: The theory used for the task. Defaults to "dft".
+            operation: The operation for the task. Defaults to "optimize".
+            theory_directives: A dict of theory directives. For example,
                 if you are running dft calculations, you may specify the
                 exchange correlation functional using {"xc": "b3lyp"}.
-            alternate_directives:
-                A dict of alternate directives. For example, to perform
-                cosmo calculations with DFT, you'd supply {'cosmo': "cosmo"}.
+            alternate_directives: A dict of alternate directives. For
+                example, to perform cosmo calculations with DFT, you'd supply
+                {'cosmo': "cosmo"}.
         """
         title = title if title is not None else "{} {} {}".format(
             re.sub("\s", "", mol.formula), theory, operation)
@@ -251,15 +234,11 @@ task $theory $operation""")
         cosmo parameter .
 
         Args:
-            mol:
-                Input molecule
-            xc:
-                Exchange correlation to use.
-            dielectric:
-                Using water dielectric
-            \*\*kwargs:
-                Any of the other kwargs supported by NwTask. Note the theory
-                is always "dft" for a dft task.
+            mol: Input molecule
+            xc: Exchange correlation to use.
+            dielectric: Using water dielectric
+            \*\*kwargs: Any of the other kwargs supported by NwTask. Note the
+                theory is always "dft" for a dft task.
         """
         t = NwTask.from_molecule(mol, theory="dft", **kwargs)
         t.theory_directives.update({"xc": xc,
@@ -273,11 +252,9 @@ task $theory $operation""")
         charge fitting.
 
         Args:
-            mol:
-                Input molecule
-            \*\*kwargs:
-                Any of the other kwargs supported by NwTask. Note the theory
-                is always "dft" for a dft task.
+            mol: Input molecule
+            \*\*kwargs: Any of the other kwargs supported by NwTask. Note the
+                theory is always "dft" for a dft task.
         """
         return NwTask.from_molecule(mol, theory="esp", **kwargs)
 
@@ -286,6 +263,21 @@ class NwInput(MSONable):
     """
     An object representing a Nwchem input file, which is essentially a list
     of tasks on a particular molecule.
+
+    Args:
+        mol: Input molecule. If molecule is a single string, it is used as a
+            direct input to the geometry section of the Gaussian input
+            file.
+        tasks: List of NwTasks.
+        directives: List of root level directives as tuple. E.g.,
+            [("start", "water"), ("print", "high")]
+        geometry_options: Additional list of options to be supplied to the
+            geometry. E.g., ["units", "angstroms", "noautoz"]. Defaults to
+            ("units", "angstroms").
+        symmetry_options: Addition list of option to be supplied to the
+            symmetry. E.g. ["c1"] to turn off the symmetry
+        memory_options: Memory controlling options. str.
+            E.g "total 1000 mb stack 400 mb"
     """
 
     def __init__(self, mol, tasks, directives=None,
@@ -293,26 +285,7 @@ class NwInput(MSONable):
                  symmetry_options=None,
                  memory_options=None):
         """
-        Args:
-            mol:
-                Input molecule. If molecule is a single string, it is used as a
-                direct input to the geometry section of the Gaussian input
-                file.
-            tasks:
-                List of NwTasks.
-            directives:
-                List of root level directives as tuple. E.g.,
-                [("start", "water"), ("print", "high")]
-            geometry_options:
-                Additional list of options to be supplied to the geometry.
-                E.g., ["units", "angstroms", "noautoz"]. Defaults to
-                ("units", "angstroms").
-            symmetry_options:
-                Addition list of option to be supplied to the symmetry.
-                E.g. ["c1"] to turn off the symmetry
-            memory_options:
-                memory controlling options. str.
-                E.g "total 1000 mb stack 400 mb"
+
         """
         self._mol = mol
         self.directives = directives if directives is not None else []
@@ -378,8 +351,7 @@ class NwInput(MSONable):
         files generated from this class itself.
 
         Args:
-            string_input:
-                string_input to parse.
+            string_input: string_input to parse.
 
         Returns:
             NwInput object
@@ -464,8 +436,7 @@ class NwInput(MSONable):
         files generated from this class itself.
 
         Args:
-            filename:
-                Filename to parse.
+            filename: Filename to parse.
 
         Returns:
             NwInput object
@@ -487,6 +458,9 @@ class NwOutput(object):
     only parses energies and geometries. Please note that Nwchem typically
     outputs energies in either au or kJ/mol. All energies are converted to
     eV in the parser.
+
+    Args:
+        filename: Filename to read.
     """
 
     def __init__(self, filename):
